@@ -19,11 +19,5 @@ ZODB Browser has the following submodules:
 """
 
 
-__version__ = '0.10.4'
+__version__ = '0.11.1'
 __homepage__ = 'http://launchpad.net/zodbbrowser'
-
-
-if __name__ == '__main__':
-    # support python -m zodbbrowser on Python 2.5
-    from zodbbrowser.standalone import main
-    main()
