@@ -10,16 +10,19 @@ from zope.component import adapts, queryUtility
 from zope.interface import Interface
 from zope.security.proxy import removeSecurityProxy
 from zope.cachedescriptors.property import Lazy
+from zope.exceptions.interfaces import UserError
 from ZODB.utils import p64, u64, tid_repr, oid_repr
 from ZODB.Connection import Connection
 from ZODB.interfaces import IDatabase
+from ZODB.POSException import POSKeyError
 from persistent import Persistent
 from persistent.TimeStamp import TimeStamp
 import transaction
 import simplejson
 
 from zodbbrowser import __version__, __homepage__
-from zodbbrowser.interfaces import IObjectHistory, IValueRenderer
+from zodbbrowser.history import ZodbObjectHistory
+from zodbbrowser.interfaces import IValueRenderer
 from zodbbrowser.interfaces import IDatabaseHistory
 from zodbbrowser.state import ZodbObjectState
 from zodbbrowser.diff import compareDictsHTML
@@ -119,7 +122,8 @@ class ZodbInfoView(VeryCarefulView):
         self._started = time.time()
         pruneTruncations()
         self.obj = self.selectObjectToView()
-        self.history = IObjectHistory(self.obj)
+        # Not using IObjectHistory(self.obj) because LP#1185175
+        self.history = ZodbObjectHistory(self.obj)
         self.latest = True
         if self.request.get('tid'):
             self.state = ZodbObjectState(self.obj,
@@ -165,10 +169,17 @@ class ZodbInfoView(VeryCarefulView):
                 obj = None
         if obj is None:
             if 'oid' in self.request:
-                oid = int(self.request['oid'], 0)
+                try:
+                    oid = int(self.request['oid'], 0)
+                except ValueError:
+                    raise UserError('OID is not an integer: %r' %
+                                    self.request['oid'])
             else:
                 oid = self.getRootOid()
-            obj = self.jar.get(p64(oid))
+            try:
+                obj = self.jar.get(p64(oid))
+            except POSKeyError:
+                raise UserError('There is no object with OID 0x%x' % oid)
         return obj
 
     def findClosestPersistent(self):
@@ -195,6 +206,9 @@ class ZodbInfoView(VeryCarefulView):
     def getObjectId(self):
         return self.state.getObjectId()
 
+    def getObjectIdHex(self):
+        return '0x%x' % self.state.getObjectId()
+
     def getObjectType(self):
         return getObjectType(self.obj)
 
@@ -425,7 +439,7 @@ class ZodbHistoryView(VeryCarefulView):
         if self.page > self.last_page:
             self.page = self.last_page
         self.last_idx = max(0, len(self.history) - self.page * self.page_size)
-        self.first_idx = max(0, self.last_idx  - self.page_size)
+        self.first_idx = max(0, self.last_idx - self.page_size)
         return self.template()
 
     def renderingTime(self):
