@@ -2,6 +2,7 @@ import unittest
 import transaction
 import sys
 import gc
+import json
 
 from ZODB.utils import u64, p64, tid_repr, oid_repr
 from ZODB.interfaces import IDatabase
@@ -111,6 +112,7 @@ class TestZodbInfoViewWithRealDb(RealDatabaseTest):
         self.root['stub'] = PersistentStub()
         self.root['stub']['member'] = NonpersistentStub()
         self.root['stub']['member']['notpersistent'] = 'string'
+        self.conn.add(self.root['stub']) # force oid allocation
         self.root['root'] = RootFolderStub()
         self.root['root']['item'] = PersistentStub()
         transaction.commit()
@@ -198,40 +200,47 @@ class TestZodbInfoViewWithRealDb(RealDatabaseTest):
 
     def testLocate(self):
         view = self._zodbInfoView(self.root, TestRequest())
-        jsonResult = view.locate_json('/')
-        self.assertTrue('"url": "@@zodbbrowser?oid=0x0"' in jsonResult)
-        self.assertTrue('"oid": 0' in jsonResult)
-        jsonResult = view.locate_json('/stub/member/notpersistent')
-        self.assertTrue('"partial_url"' in jsonResult)
-        self.assertTrue('"partial_oid"' in jsonResult)
-        self.assertTrue('"error": "Not persistent: /stub/member/notpersistent"')
-        jsonResult = view.locate_json('/stub/nonexistent')
-        self.assertTrue('"partial_url": "@@zodbbrowser?oid=0x1"' in jsonResult)
-        self.assertTrue('"partial_path": "/stub", ' in jsonResult)
-        self.assertTrue('"error": "Not found: /stub/nonexistent"}' in jsonResult)
-        self.assertTrue('"partial_oid": 1' in jsonResult)
+        jsonResult = json.loads(view.locate_json('/'))
+        self.assertEqual(jsonResult,
+                         {"url": "@@zodbbrowser?oid=0x0",
+                          "oid": 0})
+        jsonResult = json.loads(view.locate_json('/stub/member/notpersistent'))
+        self.assertTrue("partial_url" in jsonResult)
+        self.assertTrue("partial_oid" in jsonResult)
+        self.assertEqual(jsonResult["error"],
+                         "Not persistent: /stub/member/notpersistent")
+        jsonResult = json.loads(view.locate_json('/stub/nonexistent'))
+        self.assertEqual(jsonResult,
+                         {"partial_url": "@@zodbbrowser?oid=0x1",
+                          "partial_path": "/stub",
+                          "error": "Not found: /stub/nonexistent",
+                          "partial_oid": 1})
 
     def testLocateStartWithOID(self):
         view = self._zodbInfoView(self.root, TestRequest())
-        jsonResult = view.locate_json('0')
-        self.assertTrue('"url": "@@zodbbrowser?oid=0x0"' in jsonResult)
-        self.assertTrue('"oid": 0' in jsonResult)
-        jsonResult = view.locate_json('0x0')
-        self.assertTrue('"url": "@@zodbbrowser?oid=0x0"' in jsonResult)
-        self.assertTrue('"oid": 0' in jsonResult)
-        jsonResult = view.locate_json('0x1/nonexistent')
-        self.assertTrue('"partial_url": "@@zodbbrowser?oid=0x1"' in jsonResult)
-        self.assertTrue('"partial_path": "0x1", ' in jsonResult)
-        self.assertTrue('"error": "Not found: 0x1/nonexistent"}' in jsonResult)
-        self.assertTrue('"partial_oid": 1' in jsonResult)
+        jsonResult = json.loads(view.locate_json('0'))
+        self.assertEqual(jsonResult,
+                         {"url": "@@zodbbrowser?oid=0x0",
+                          "oid": 0})
+        jsonResult = json.loads(view.locate_json('0x0'))
+        self.assertEqual(jsonResult,
+                         {"url": "@@zodbbrowser?oid=0x0",
+                          "oid": 0})
+        jsonResult = json.loads(view.locate_json('0x1/nonexistent'))
+        self.assertEqual(jsonResult,
+                         {"partial_url": "@@zodbbrowser?oid=0x1",
+                          "partial_path": "0x1",
+                          "error": "Not found: 0x1/nonexistent",
+                          "partial_oid": 1})
 
     def testLocateStartWithOID_that_does_not_exist(self):
         view = self._zodbInfoView(self.root, TestRequest())
-        jsonResult = view.locate_json('0x1234')
-        self.assertTrue('"partial_url": "@@zodbbrowser?oid=0x0"' in jsonResult)
-        self.assertTrue('"partial_path": "/", ' in jsonResult)
-        self.assertTrue('"error": "Not found: 0x1234"}' in jsonResult)
-        self.assertTrue('"partial_oid": 0' in jsonResult)
+        jsonResult = json.loads(view.locate_json('0x1234'))
+        self.assertEqual(jsonResult,
+                         {"partial_url": "@@zodbbrowser?oid=0x0",
+                          "partial_path": "/",
+                          "error": "Not found: 0x1234",
+                          "partial_oid": 0})
 
     def testGetUrl(self):
         view = self._zodbInfoView(self.root, TestRequest())
@@ -300,38 +309,33 @@ class TestZodbInfoViewBreadcrumbs(unittest.TestCase):
     def test_root(self):
         view = self.createView(self.root)
         self.assertEquals(view.getBreadcrumbs(),
-                          [('/', '@@zodbbrowser?oid=0x1'),
-                          ])
+                          [('/', '@@zodbbrowser?oid=0x1'), ])
 
     def test_non_root(self):
         view = self.createView(self.foo)
         self.assertEquals(view.getBreadcrumbs(),
                           [('/', '@@zodbbrowser?oid=0x1'),
-                           ('foo','@@zodbbrowser?oid=0x1b'),
-                          ])
+                           ('foo', '@@zodbbrowser?oid=0x1b'), ])
 
     def test_more_levels(self):
         view = self.createView(self.foobar)
         self.assertEquals(view.getBreadcrumbs(),
                           [('/', '@@zodbbrowser?oid=0x1'),
-                           ('foo','@@zodbbrowser?oid=0x1b'),
+                           ('foo', '@@zodbbrowser?oid=0x1b'),
                            ('/', None),
-                           ('bar','@@zodbbrowser?oid=0x20'),
-                          ])
+                           ('bar', '@@zodbbrowser?oid=0x20'), ])
 
     def test_unknown(self):
         view = self.createView(self.unknown)
         self.assertEquals(view.getBreadcrumbs(),
-                          [('0xf','@@zodbbrowser?oid=0xf'),
-                          ])
+                          [('0xf', '@@zodbbrowser?oid=0xf'), ])
 
     def test_unknown_child(self):
         view = self.createView(self.unknown_child)
         self.assertEquals(view.getBreadcrumbs(),
-                          [('0xf','@@zodbbrowser?oid=0xf'),
+                          [('0xf', '@@zodbbrowser?oid=0xf'),
                            ('/', None),
-                           ('child', '@@zodbbrowser?oid=0x11'),
-                          ])
+                           ('child', '@@zodbbrowser?oid=0x11'), ])
 
     def test_unparented(self):
         view = self.createView(self.unparented)
@@ -339,15 +343,13 @@ class TestZodbInfoViewBreadcrumbs(unittest.TestCase):
                           [('/', '@@zodbbrowser?oid=0x1'),
                            ('...', None),
                            ('/', None),
-                           ('wat', '@@zodbbrowser?oid=0x13'),
-                          ])
+                           ('wat', '@@zodbbrowser?oid=0x13'), ])
 
     def test_unnamed_direct_child_of_root(self):
         view = self.createView(self.unnamed)
         self.assertEquals(view.getBreadcrumbs(),
                           [('/', '@@zodbbrowser?oid=0x1'),
-                           ('???', '@@zodbbrowser?oid=0x37'),
-                          ])
+                           ('???', '@@zodbbrowser?oid=0x37'), ])
 
 
 class TestZodbInfoView(unittest.TestCase):
